#ifndef NOMAD_JUKEBOX_JOB_H
#define NOMAD_JUKEBOX_JOB_H

typedef enum {
	GET_TIME,
	BUILD_TRACKLIST,
	SET_OWNER_STRING,
	GET_USAGE,
	UPLOAD,
	DOWNLOAD,
	DELETE_TRACKS,
	SET_METADATA,

	SET_EAX,

	PLAY_TRACK,
	PLAY_ELAPSED,
	PLAY_STOP,

	TERMINATE,

	BUILD_PLAYLIST,


	DELETE_TRACKS_FROM_PLAYLIST,
	CREATE_PLAYLIST,
	DELETE_PLAYLIST,
	RENAME_PLAYLIST,
	ADD_TO_PLAYLIST,

	MAX_JOB_NUM
} NomadJukeboxJobType;

typedef struct {
	NomadJukeboxJobType type;

	guint id;
	guint priority;

	/* so we can pass some data in, a list for example,
	   or a pointer to a struct we need 3 params at most so
	   just have 3 data items */
	gpointer data;
	gpointer data2;
	gpointer data3;
} NomadJukeboxJob;

#endif
